@@ -1,7 +1,7 @@
 ## this returns the model to be used
 ## no. of parameters in the model
 ## do not allow to fix all params (only p-1) ???
-thetalogistic_D <- 
+thetalogistic_D <-
 function(obs.error="none", fixed)
 {
 
@@ -83,7 +83,7 @@ function(obs.error="none", fixed)
     cm_end_P <- cm_end_0
 
     ## match observation error type
-    obs.error <- match.arg(tolower(obs.error), 
+    obs.error <- match.arg(tolower(obs.error),
         c("none", "normal", "poisson"))
     ## put together the model file
     cm_lik <- switch(obs.error,
@@ -101,13 +101,13 @@ function(obs.error="none", fixed)
         "normal"  = 6)
     ## range of support for parameters
     support <- switch(obs.error,
-        "none"    = rbind(r=c(-Inf, Inf), K=c(.Machine$double.eps, Inf), 
+        "none"    = rbind(r=c(-Inf, Inf), K=c(.Machine$double.eps, Inf),
             theta=c( -Inf, Inf), sigma=c(.Machine$double.eps, Inf),
             sigma2.d=c(.Machine$double.eps, Inf)),
-        "poisson" = rbind(r=c(-Inf, Inf), K=c(.Machine$double.eps, Inf), 
+        "poisson" = rbind(r=c(-Inf, Inf), K=c(.Machine$double.eps, Inf),
             theta=c( -Inf, Inf), sigma=c(.Machine$double.eps, Inf),
             sigma2.d=c(.Machine$double.eps, Inf)),
-        "normal"  = rbind(r=c(-Inf, Inf), K=c(.Machine$double.eps, Inf), 
+        "normal"  = rbind(r=c(-Inf, Inf), K=c(.Machine$double.eps, Inf),
             theta=c( -Inf, Inf), sigma=c(.Machine$double.eps, Inf),
             tau=c(.Machine$double.eps, Inf),
             sigma2.d=c(.Machine$double.eps, Inf)))
@@ -176,13 +176,13 @@ function(obs.error="none", fixed)
             if (is.character(fixed[["sigma2.d"]])) {
                 cm_end["sigma2.d"] <- fixed[["sigma2.d"]]
             } else {
-                if (fixed[["sigma2.d"]] < support["sigma2.d","Min"] || 
+                if (fixed[["sigma2.d"]] < support["sigma2.d","Min"] ||
                     fixed[["sigma2.d"]] > support["sigma2.d","Max"])
                     stop("support for fixed parameter 'sigma2.d' ill-defined")
                 cm_end["sigma2.d"] <- paste("     sigma2.d <-", round(fixed[["sigma2.d"]], 4))
             }
         }
-        fixed <- unlist(lapply(fixed, function(z) 
+        fixed <- unlist(lapply(fixed, function(z)
             ifelse(is.numeric(z), z, NA)))
         fixed <- fixed[!is.na(fixed)]
         if (!length(fixed))
@@ -191,8 +191,8 @@ function(obs.error="none", fixed)
     ## put together stuff
     model <- structure(c(cm_lik, unname(cm_end)),
             class = "custommodel")
-    fancy <- c("Theta Logistic D", 
-        ifelse(obs.error=="none", NA, 
+    fancy <- c("Theta Logistic D",
+        ifelse(obs.error=="none", NA,
             gsub("\\b(\\w)", "\\U\\1", obs.error, perl=TRUE)))
     ## list params (fixed will not be a parameter)
     params <- switch(obs.error,
@@ -207,7 +207,8 @@ function(obs.error="none", fixed)
 
     ## this scales diagnostic parameters to the scale of the summaries
     backtransf <- function(mcmc, obs.error) {
-        mcmc <- as.mcmc.list(mcmc)
+        #mcmc <- as.mcmc.list(mcmc)
+        mcmc <- as(mcmc, "mcmc.list")
         vn <- varnames(mcmc)
         for (i in seq_len(nchain(mcmc))) {
             if ("z" %in% vn)
@@ -228,7 +229,8 @@ function(obs.error="none", fixed)
     }
     ## this scales summaries to the scale of diagnostic parameters
     transf <- function(mcmc, obs.error) {
-        mcmc <- as.mcmc.list(mcmc)
+        #mcmc <- as.mcmc.list(mcmc)
+        mcmc <- as(mcmc, "mcmc.list")
         vn <- varnames(mcmc)
         for (i in seq_len(nchain(mcmc))) {
             if ("b" %in% vn)
@@ -259,7 +261,7 @@ function(obs.error="none", fixed)
         ## data: data on original scale (this is used to check missing values)
         ## null_obserror: logical, if the null model has obs error
         ## alt_obserror: logical, if the alternative model has obs error
-        "none"    = function(logx, mle, data, 
+        "none"    = function(logx, mle, data,
         null_obserror=FALSE, alt_obserror=FALSE) {
             T <- length(logx)
             m <- which(is.na(data))
@@ -269,10 +271,10 @@ function(obs.error="none", fixed)
                     ## null is NOE, alt is OE, NA present (II.a)
 ##                    ii <- ts_index(data)
 ##                    jj <- setdiff(which(!is.na(data)), ii)
-##                    do <- sum(dnorm(data[jj][-1], 
+##                    do <- sum(dnorm(data[jj][-1],
 ##                        mean= mle["r"] + mle["b"] * data[jj-1][-length(jj)],
 ##                        sd = mle["sigma"], log=TRUE))
-##                    expect <- log(mean(dnorm(data[ii], 
+##                    expect <- log(mean(dnorm(data[ii],
 ##                        mean= mle["a"] + mle["b"] * logx[ii-1],
 ##                        sd = mle["sigma"], log=FALSE)))
 ##                    rval <- do + expect
@@ -305,7 +307,7 @@ function(obs.error="none", fixed)
             rval
         },
         ## data on the log scale
-        "poisson" = function(logx, mle, data, 
+        "poisson" = function(logx, mle, data,
         null_obserror=FALSE, alt_obserror=FALSE) {
             T <- length(data)
             if (!(!null_obserror && any(is.na(data)))) {
@@ -322,7 +324,7 @@ function(obs.error="none", fixed)
             rval
         },
         ## data on the log scale
-        "normal"  = function(logx, mle, data, 
+        "normal"  = function(logx, mle, data,
         null_obserror=FALSE, alt_obserror=FALSE) {
             T <- length(data)
             if (!(!null_obserror && any(is.na(data)))) {
@@ -335,8 +337,8 @@ function(obs.error="none", fixed)
                 rval <- sum(logd1) + sum(logd2, na.rm=TRUE)
             } else {
                 stop("not yet implemented")
-##                rval <- sum(dnorm(data, 
-##                    mean=logx, 
+##                rval <- sum(dnorm(data,
+##                    mean=logx,
 ##                    sd=mle["sigma"], log=TRUE), na.rm=TRUE)
             }
             rval
